==> coretool-0.0.4-py3-none-any.whl: __init__.py <==
from .coretool_middlewares import CORSMiddleware, open_access_middleware
from .coretool import (GenView, api_generate_serializer_class, generate_gen_view, generate_urlpatterns_gens_view,
                       b64_to_img, image_name_for_save, generate_ean13, BarcodeTypes, barcode_generate_fullcode,
                       barcode_generate_file, AbstractStatic, tools_classes_import_from_str2,
                       tools_classes_import_from_str, ToolsCsv, dt_add_one_month, dt_convert24, dt_str_to_dt24_format,
                       dt_str_to_time24_format,
                       dt_time_to_operatable_format,
                       dt_get_dayname, dt_are_these_dates_intersected, dt_difftimedelta_str, get_data_model_bd_set,
                       set_attribute, admin_descripcion, admin_ordenarpor, CsvImportForm, CsvExportMixin, CsvImport,
                       empaquetar_zip, get_size_mb, image_compress, image_rename_for_upload, image_name_for_save,
                       images_compress_save,
                       img_app_resize_save, image_bytearray_to_img, b64_to_img, image_get_content_file_from_bytearray,
                       tools_json_dict_merge, tools_json_dict_all_to_str, net_get_abs_url,
                       tools_objects_getattributes_values, tools_objects_getmembers, ZipResponse, strings_just_numbers,
                       strings_just_letters, strings_currency_format, strings_currency_gs,
                       strings_get_fcurrency_value, strings_get_s_numer, strings_array_values_to_str,
                       strings_generate_code, strings_generate_token_urlsafe, strings_generate_random_password,
                       strings_normalize_str, strings_normalize_slower_str, strings_delete_duplicates,
                       strings_seeker_iregex_and, strings_seeker_iregex_or, validator_no_espacios,
                       validators_throw_error_basic)

==> coretool-0.0.5-py3-none-any.whl: __init__.py <==
from .coretool_middlewares import CORSMiddleware, open_access_middleware
from .coretool import (GenView, api_generate_serializer_class, generate_gen_view, generate_urlpatterns_gens_view,
                       b64_to_img, image_name_for_save, generate_ean13, BarcodeTypes, barcode_generate_fullcode,
                       barcode_generate_file, AbstractStatic, tools_classes_import_from_str2,
                       tools_classes_import_from_str, ToolsCsv, dt_add_one_month, dt_convert24, dt_str_to_dt24_format,
                       dt_str_to_time24_format,
                       dt_time_to_operatable_format,
                       dt_get_dayname, dt_are_these_dates_intersected, dt_difftimedelta_str, get_data_model_bd_set,
                       set_attribute, admin_descripcion, admin_ordenarpor, CsvImportForm, CsvExportMixin, CsvImport,
                       empaquetar_zip, get_size_mb, image_compress, image_rename_for_upload, image_name_for_save,
                       images_compress_save, img_app_resize_save, image_bytearray_to_img, b64_to_img,
                       image_get_content_file_from_bytearray, tools_json_dict_merge, tools_json_dict_all_to_str,
                       net_get_abs_url,
                       tools_objects_getattributes_values, tools_objects_getmembers, ZipResponse, strings_just_numbers,
                       strings_just_letters, strings_currency_format, strings_currency_gs,
                       strings_get_fcurrency_value, strings_get_s_numer, strings_array_values_to_str,
                       strings_generate_code, strings_generate_token_urlsafe, strings_generate_random_password,
                       strings_normalize_str, strings_normalize_slower_str, strings_delete_duplicates,
                       strings_seeker_iregex_and, strings_seeker_iregex_or, validator_no_espacios,
                       validators_throw_error_basic, ApiBasicController, ApiRestBaseController,
                       ApiRestAbstractController, ApiRestStandard, PROCESS_TYPES, CrudBasic)
